==> openshift-model-console-5.10.1-sources.jar: io/fabric8/openshift/api/model/console/v1/ConsoleQuickStartTaskReviewFluentImpl.java <==
package io.fabric8.openshift.api.model.console.v1;

import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.String;
import java.lang.Boolean;
import java.util.Map;
import java.util.LinkedHashMap;

 /**
  * Generated
  */
public class ConsoleQuickStartTaskReviewFluentImpl<A extends io.fabric8.openshift.api.model.console.v1.ConsoleQuickStartTaskReviewFluent<A>> extends io.fabric8.kubernetes.api.builder.BaseFluent<A> implements io.fabric8.openshift.api.model.console.v1.ConsoleQuickStartTaskReviewFluent<A>{
  public ConsoleQuickStartTaskReviewFluentImpl() {
  }
  public ConsoleQuickStartTaskReviewFluentImpl(io.fabric8.openshift.api.model.console.v1.ConsoleQuickStartTaskReview instance) {
    this.withFailedTaskHelp(instance.getFailedTaskHelp()); 
    this.withInstructions(instance.getInstructions()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

  }
  private java.lang.String failedTaskHelp;
  private java.lang.String instructions;
  private java.util.Map<java.lang.String,java.lang.Object> additionalProperties;
  public java.lang.String getFailedTaskHelp() {
    return this.failedTaskHelp;
  }
  public A withFailedTaskHelp(java.lang.String failedTaskHelp) {
    this.failedTaskHelp=failedTaskHelp; return (A) this;
  }
  public java.lang.Boolean hasFailedTaskHelp() {
    return this.failedTaskHelp != null;
  }
  
  /**
   * Method is deprecated. use withFailedTaskHelp instead.
   */
  @java.lang.Deprecated
  public A withNewFailedTaskHelp(java.lang.String arg0) {
    return (A)withFailedTaskHelp(new String(arg0));
  }
  public java.lang.String getInstructions() {
    return this.instructions;
  }
  public A withInstructions(java.lang.String instructions) {
    this.instructions=instructions; return (A) this;
  }
  public java.lang.Boolean hasInstructions() {
    return this.instructions != null;
  }
  
  /**
   * Method is deprecated. use withInstructions instead.
   */
  @java.lang.Deprecated
  public A withNewInstructions(java.lang.String arg0) {
    return (A)withInstructions(new String(arg0));
  }
  public A addToAdditionalProperties(java.lang.String key,java.lang.Object value) {
    if(this.additionalProperties == null && key != null && value != null) { this.additionalProperties = new java.util.LinkedHashMap<java.lang.String,java.lang.Object>(); }
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (A)this;
  }
  public A addToAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map) {
    if(this.additionalProperties == null && map != null) { this.additionalProperties = new java.util.LinkedHashMap<java.lang.String,java.lang.Object>(); }
    if(map != null) { this.additionalProperties.putAll(map);} return (A)this;
  }
  public A removeFromAdditionalProperties(java.lang.String key) {
    if(this.additionalProperties == null) { return (A) this; }
    if(key != null && this.additionalProperties != null) {this.additionalProperties.remove(key);} return (A)this;
  }
  public A removeFromAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map) {
    if(this.additionalProperties == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.additionalProperties != null){this.additionalProperties.remove(key);}}} return (A)this;
  }
  public java.util.Map<java.lang.String,java.lang.Object> getAdditionalProperties() {
    return this.additionalProperties;
  }
  public <K,V>A withAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> additionalProperties) {
    if (additionalProperties == null) { this.additionalProperties =  null;} else {this.additionalProperties = new java.util.LinkedHashMap<java.lang.String,java.lang.Object>(additionalProperties);} return (A) this;
  }
  public java.lang.Boolean hasAdditionalProperties() {
    return this.additionalProperties != null;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    ConsoleQuickStartTaskReviewFluentImpl that = (ConsoleQuickStartTaskReviewFluentImpl) o;
    if (failedTaskHelp != null ? !failedTaskHelp.equals(that.failedTaskHelp) :that.failedTaskHelp != null) return false;
    if (instructions != null ? !instructions.equals(that.instructions) :that.instructions != null) return false;
    if (additionalProperties != null ? !additionalProperties.equals(that.additionalProperties) :that.additionalProperties != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(failedTaskHelp,  instructions,  additionalProperties,  super.hashCode());
  }
  
}

==> openshift-model-console-5.12.1-sources.jar: io/fabric8/openshift/api/model/console/v1/ConsoleQuickStartTaskReviewFluentImpl.java <==
package io.fabric8.openshift.api.model.console.v1;

import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.String;
import java.lang.Boolean;
import java.util.Map;
import java.util.LinkedHashMap;

 /**
  * Generated
  */
public class ConsoleQuickStartTaskReviewFluentImpl<A extends io.fabric8.openshift.api.model.console.v1.ConsoleQuickStartTaskReviewFluent<A>> extends io.fabric8.kubernetes.api.builder.BaseFluent<A> implements io.fabric8.openshift.api.model.console.v1.ConsoleQuickStartTaskReviewFluent<A>{
  public ConsoleQuickStartTaskReviewFluentImpl() {
  }
  public ConsoleQuickStartTaskReviewFluentImpl(io.fabric8.openshift.api.model.console.v1.ConsoleQuickStartTaskReview instance) {
    this.withFailedTaskHelp(instance.getFailedTaskHelp()); 
    this.withInstructions(instance.getInstructions()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

  }
  private java.lang.String failedTaskHelp;
  private java.lang.String instructions;
  private java.util.Map<java.lang.String,java.lang.Object> additionalProperties;
  public java.lang.String getFailedTaskHelp() {
    return this.failedTaskHelp;
  }
  public A withFailedTaskHelp(java.lang.String failedTaskHelp) {
    this.failedTaskHelp=failedTaskHelp; return (A) this;
  }
  public java.lang.Boolean hasFailedTaskHelp() {
    return this.failedTaskHelp != null;
  }
  
  /**
   * Method is deprecated. use withFailedTaskHelp instead.
   */
  @java.lang.Deprecated
  public A withNewFailedTaskHelp(java.lang.String arg0) {
    return (A)withFailedTaskHelp(new String(arg0));
  }
  public java.lang.String getInstructions() {
    return this.instructions;
  }
  public A withInstructions(java.lang.String instructions) {
    this.instructions=instructions; return (A) this;
  }
  public java.lang.Boolean hasInstructions() {
    return this.instructions != null;
  }
  
  /**
   * Method is deprecated. use withInstructions instead.
   */
  @java.lang.Deprecated
  public A withNewInstructions(java.lang.String arg0) {
    return (A)withInstructions(new String(arg0));
  }
  public A addToAdditionalProperties(java.lang.String key,java.lang.Object value) {
    if(this.additionalProperties == null && key != null && value != null) { this.additionalProperties = new java.util.LinkedHashMap(); }
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (A)this;
  }
  public A addToAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map) {
    if(this.additionalProperties == null && map != null) { this.additionalProperties = new java.util.LinkedHashMap(); }
    if(map != null) { this.additionalProperties.putAll(map);} return (A)this;
  }
  public A removeFromAdditionalProperties(java.lang.String key) {
    if(this.additionalProperties == null) { return (A) this; }
    if(key != null && this.additionalProperties != null) {this.additionalProperties.remove(key);} return (A)this;
  }
  public A removeFromAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map) {
    if(this.additionalProperties == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.additionalProperties != null){this.additionalProperties.remove(key);}}} return (A)this;
  }
  public java.util.Map<java.lang.String,java.lang.Object> getAdditionalProperties() {
    return this.additionalProperties;
  }
  public <K,V>A withAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> additionalProperties) {
    if (additionalProperties == null) { this.additionalProperties =  null;} else {this.additionalProperties = new java.util.LinkedHashMap(additionalProperties);} return (A) this;
  }
  public java.lang.Boolean hasAdditionalProperties() {
    return this.additionalProperties != null;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    ConsoleQuickStartTaskReviewFluentImpl that = (ConsoleQuickStartTaskReviewFluentImpl) o;
    if (failedTaskHelp != null ? !failedTaskHelp.equals(that.failedTaskHelp) :that.failedTaskHelp != null) return false;
    if (instructions != null ? !instructions.equals(that.instructions) :that.instructions != null) return false;
    if (additionalProperties != null ? !additionalProperties.equals(that.additionalProperties) :that.additionalProperties != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(failedTaskHelp,  instructions,  additionalProperties,  super.hashCode());
  }
  
}
